#include <algorithm>
#include <iostream>
#include <vector>
#include <map>
#include <cassert>
#include <cmath>

using namespace std;


namespace Geom2d {

    using ll = long double;
    const double pi = acos(-1);
    const double eps = 1e-8;

    struct point {
        ll x, y;
        point(ll _x = 0, ll _y = 0) {
            x = _x, y = _y;
        }
    };

    const point ERRPoint = point(-1e12, -1e12);

    istream& operator >>(istream& fin, point& p) {
        return fin >> p.x >> p.y;
    }

    ostream& operator <<(ostream& fout, point& p) {
        return fout << p.x << ' ' << p.y << ' ';
    }

    bool operator ==(point a, point b) {
        return a.x == b.x && a.y == b.y;
    }

    bool operator !=(point a, point b) {
        return !(a == b);
    }

    bool operator <(point a, point b) {
        return make_pair(a.x, a.y) < make_pair(b.x, b.y);
    }

    bool operator >(point a, point b) {
        return b < a;
    }

    bool operator <=(point a, point b) {
        return !(b < a);
    }

    bool operator >=(point a, point b) {
        return !(a < b);
    }

    ll dist(point a, point b) {
        return (b.x - a.x) * (b.x - a.x) + (b.y - a.y) * (b.y - a.y);
    }

    double sqdist(point a, point b) {
        return sqrt((double)dist(a, b));
    }

    struct vect {
        ll x, y;
        vect(ll _x = 0, ll _y = 0) {
            x = _x, y = _y;
        }
        vect(point a) {
            x = a.x, y = a.y;
        }
    };

    const vect ERRVect = vect(-1e12, -1e12);

    vect operator +(vect a, vect b) {
        return vect(a.x + b.x, a.y + b.y);
    }

    vect operator -(vect a, vect b) {
        return vect(a.x - b.x, a.y - b.y);
    }

    vect operator *(vect a, ll k) {
        return vect(a.x * k, a.y * k);
    }

    vect operator /(vect a, ll k) {
        return vect(a.x / k, a.y / k);
    }

    ll operator *(vect a, vect b) {
        return a.x * b.x + a.y * b.y;
    }

    ll operator ^(vect a, vect b) {
        return a.x * b.y - b.x * a.y;
    }

    ll dist(vect a) {
        return a.x * a.x + a.y * a.y;
    }

    double sqdist(vect a) {
        return sqrt((double)dist(a));
    }

    bool operator ==(vect a, vect b) {
        return a.x == b.x && a.y == b.y;
    }

    bool operator !=(vect a, vect b) {
        return !(a == b);
    }

    bool operator <(vect a, vect b) {
        int f1 = a.y > 0 || a.y == 0 && a.x > 0;
        int f2 = b.y > 0 || b.y == 0 && b.x > 0;
        if (f1 != f2) return f1 < f2;
        ll v = a ^ b;
        if (v == 0) return dist(a) < dist(b);
        else return v > 0;
    }

    bool operator >(vect a, vect b) {
        return b < a;
    }

    bool operator <=(vect a, vect b) {
        return !(b < a);
    }

    bool operator >=(vect a, vect b) {
        return !(a < b);
    }

    point operator +(point a, vect b) {
        return point(a.x + b.x, a.y + b.y);
    }

    vect operator -(point a, point b) {
        return vect(a.x - b.x, a.y - b.y);
    }

    vect norm(vect a) {
        return a / sqdist(a);
    }

    vect rotate(vect v, double angle) {
		double cs = cos(angle), sn = sin(angle);
        return vect(v.x * cs - v.y * sn, v.x * sn + v.y * cs);
    }

    double angle(vect a, vect b) {
        return atan2(a ^ b, a * b);
    }

    struct line {
        ll a, b, c;
        line(ll _a = 0, ll _b = 0, ll _c = 0) {
            a = _a, b = _b, c = _c;
        }
        line(point p1, point p2) {
            a = p1.y - p2.y, b = p2.x - p1.x, c = p1.x * p2.y - p2.x * p1.y;
        }
    };

    const line ERRLine = line(0, 0, 0);

    bool on_line(line l, point p) {
        return l.a * p.x + l.b * p.y + l.c == 0;
    }

    ll dist(point a, line l) {
        ll val = l.a * a.x + l.b * a.y + l.c;
        return (val * val) / (l.a * l.a + l.b * l.b);
    }

    double sqdist(point a, line l) {
        return sqrt((double)dist(a, l));
    }

    point intersect(line l1, line l2) {
        ll det = l1.a * l2.b - l2.a * l1.b;
        if (det == 0) return ERRPoint;
        return point((l2.c * l1.b - l1.c * l2.b) / det, -(l2.c * l1.a - l1.c * l2.a) / det);
    }

    line move(line l, vect a) {
        return line(l.a, l.b, l.c - l.a * a.x - l.b * a.y);
    }

    point proection(point p, line l) {
        vect v = vect(l.a, l.b);
        ll d = (l.a * p.x + l.b * p.y + l.c) / dist(v);
        if (!on_line(l, p + v * d)) v = v * -1;
        return p + v * d;
    }

    point get_point(line l, ll c) {
        if (l.a != 0) {
            return point((-l.c - l.b * c) / l.a, c);
        }
        if (l.b != 0) {
            return point(c, (-l.c - l.a * c) / l.b);
        }
    }

    struct circle {
        point c;
        ll r;
        circle() {
            c = point(0, 0), r = 0;
        }
        circle(point _p, ll _r = 0) {
            c = _p;
            r = _r;
        }
    };

    bool on_circle(circle c, point p) {
        return dist(c.c, p) == c.r * c.r;
    }

    pair<point, point> intersect(circle c, line l) {
        point p0 = proection(c.c, l);
        vect v = c.c - p0;
        if (dist(v) > c.r * c.r) return {ERRPoint, ERRPoint};
        double d = sqrt(c.r * c.r - dist(v));
        vect v1 = norm(vect(-l.b, l.a)) * d;
        vect v2 = norm(vect(l.b, -l.a)) * d;
        return {p0 + v1, p0 + v2};
    }

    bool in_convex_polygon(vector<point> &a, point p) {
        int n = (int)a.size();
        vect v = p - a[0];
        if ((v ^ (a[1] - a[0])) > 0 || (v ^ (a[n - 1] - a[0])) < 0) {
            return false;
        }
        int l = 1;
        int r = n - 1;
        while (r - l > 1) {
            int m = (l + r) / 2;
            vect cur = a[m] - a[0];
            if ((cur ^ v) > 0) l = m;
            else r = m;
        }
        ll val1 = (a[r] - a[l]) ^ (a[0] - a[l]), val2 = (a[r] - a[l]) ^ (p - a[l]);
        return val1 == 0 || val2 == 0 || val1 / abs(val1) == val2 / abs(val2);
    }

    bool in_polygon(vector<point> &a, point p) {
        int n = (int)a.size();
        double ang = 0;
        for (int i = 0; i < n; i++) {
            vect v1 = a[i] - p, v2 = a[(i + 1) % n] - p;
            if ((v1 ^ v2) == 0 && (v1 * v2) <= 0) return true;
            ang += angle(v1, v2);
        }
        return abs(ang) > pi;
    }

    vector<point> convex_hull(vector<point> a) {
        sort(a.begin(), a.end());
        a.resize(unique(a.begin(), a.end()) - a.begin());
        int n = (int)a.size();
        point p0 = *(min_element(a.begin(), a.end()));
        vector<vect> vects;
        for (int i = 0; i < n; i++) {
            if (a[i] != p0) {
                vects.push_back(a[i] - p0);
            }
        }
        n = (int)vects.size();
        sort(vects.begin(), vects.end());
        vector<point> st;
        st.push_back(point(0, 0));
        for (int i = 0; i < n; i++) {
            point cur = point(vects[i].x, vects[i].y);
            while (st.size() > 1) {
                point p1 = st[st.size() - 2], p2 = st[st.size() - 1];
                if (((p2 - p1) ^ (cur - p2)) > 0) break;
                st.pop_back();
            }
            st.push_back(cur);
        }
        vector<point> ans;
        for (int i = 0; i < (int)st.size(); i++) {
            ans.push_back(p0 + vect(st[i]));
        }
        return ans;
    }

    ll square(vector<point> &a) {
        int n = (int)a.size();
        ll ans = 0;
        for (int i = 1; i < n - 1; i++) {
            ans += (a[i] - a[0]) ^ (a[i + 1] - a[0]);
        }
        return abs(ans);
    }

    point intersect(vector<line> a) {
        random_shuffle(a.begin(), a.end());
        a.insert(a.begin(), line(1, 0, 1e12));
        int n = (int)a.size();
        point cur = point(-1e12, 0);
        for (int i = 1; i < n; i++) {
            if (a[i].a * cur.x + a[i].b * cur.y + a[i].c >= 0) continue;
            vect dir1 = norm(vect(-a[i].b, a[i].a));
            point q = get_point(a[i], 0);
            point cur1 = ERRPoint, cur2 = ERRPoint;
            ll val1 = -1e12, val2 = 1e12;
            for (int j = 0; j < i; j++) {
                point p = intersect(a[j], a[i]);
                if (p == ERRPoint) {
                    if (a[j].a * q.x + a[j].b * q.y + a[j].c < 0) return ERRPoint;
                    else continue;
                }
                vect norm2 = vect(a[j].a, a[j].b);
                ll val = vect(p) * dir1;
                if (dir1 * norm2 > 0 && val1 < val) cur1 = p, val1 = val;
                else if (dir1 * norm2 < 0 && val2 > val) cur2 = p, val2 = val;
            }
            if (val1 > val2) return ERRPoint;
            if (cur1 != ERRPoint || cur2 != ERRPoint) cur = min(cur1, cur2);
            else cur = q;
        }
        return cur;
    }
}

using namespace Geom2d;

const int maxnum = 1e6;
const double eps1 = 1e-6;

const int mod = 1000000007;

int fact[2 * maxnum];

void precalc_fact() {
    fact[0] = 1;
    for (int i = 1; i < 2 * maxnum; i++) {
        fact[i] = (long long)fact[i - 1] * i % mod;
    }
}

int power(int a, int x) {
    if (x == 0) return 1;
    if (x % 2 == 1) {
        return (long long)a * power(a, x - 1) % mod;
    } else {
        long long c = power(a, x / 2);
        return c * c % mod;
    }
}

int rev(int a) {
    return power(a, mod - 2);
}

int cc(int n, int k) {
    if (n < k) return 0;
    long long res = fact[n];
    res = (res * rev(fact[k])) % mod;
    res = (res * rev(fact[n - k])) % mod;
    return res;
}

int main() {
    precalc_fact();
    int t;
    cin >> t;
    while (t--) {
        point a, b, c;
        cin >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y;
        vector<pair<point, point>> tr = {{a, b}, {b, c}, {c, a}};
        int ans = 0;
        for (int num = 0; num <= maxnum; num++) {
            line l = line(1, -1, 2 * num);
            vector<point> ps;
            for (const auto& seg : tr) {
                line edge = line(seg.first, seg.second);
                point inter = intersect(edge, l);
                if (inter == ERRPoint) continue;
                ll prod = (seg.first - inter) * (seg.second - inter);
                if (prod < eps1) {
                    ps.push_back(inter);
                }
            }
            sort(ps.begin(), ps.end());
            ps.resize(unique(ps.begin(), ps.end(), [](const point& a, const point& b) {
                return abs(b.x - a.x) < eps1 && abs(b.y - a.y) < eps1;
            }) - ps.begin());
            //cout << ps.size() << endl;
            if (ps.size() == 1) ps.push_back(ps[0]);
            if (ps.empty()) continue;
            assert(ps.size() == 2);
            point left = ps[0], right = ps[1];
            //cout << "left: " << left.x << ' ' << left.y << endl;
            //cout << "right: " << right.x << ' ' << right.y << endl;
            int n1 = ceil(left.y - eps1);
            int n2 = floor(right.y + eps1);
            int k = num;
            n1 = max(n1, k);
            //cout << n1 << ' ' << k << ' ' << n2 << ' ' << k << endl;
            if (n1 > n2) continue;
            ans += cc(n2 + 1, k + 1) - cc(n1, k + 1);
            ans %= mod;
            if (ans < 0) ans += mod;
        }
        cout << ans << '\n';
    }
}